genshi.template.astutil.ASTTransformer

Package genshi :: Package template :: Module astutil :: Class ASTTransformer |

# Class ASTTransformer

    object --+
             |
            ASTTransformer

Known Subclasses:
  - eval.TemplateASTTransformer

General purpose base class for AST transformations.

Every visitor method can be overridden to return an AST node that has been altered or replaced in some way.

Instance Methods
visit(self, node) |
visit_Module(self, node) |
visit_Interactive(self, node) |
visit_Expression(self, node) |
visit_Suite(self, node) |
visit_FunctionDef(self, node) |
visit_ClassDef(self, node) |
visit_Return(self, node) |
visit_Delete(self, node) |
visit_Assign(self, node) |
visit_AugAssign(self, node) |
visit_Print(self, node) |
visit_For(self, node) |
visit_While(self, node) |
visit_If(self, node) |
visit_With(self, node) |
visit_Raise(self, node) |
visit_TryExcept(self, node) |
visit_TryFinally(self, node) |
visit_Assert(self, node) |
visit_ExceptHandler(self, node) |
visit_Import(self, node) |
visit_ImportFrom(self, node) |
visit_Exec(self, node) |
visit_Global(self, node) |
visit_Expr(self, node) |
visit_BoolOp(self, node) |
visit_BinOp(self, node) |
visit_UnaryOp(self, node) |
visit_Lambda(self, node) |
visit_IfExp(self, node) |
visit_Dict(self, node) |
visit_ListComp(self, node) |
visit_GeneratorExp(self, node) |
visit_Yield(self, node) |
visit_Compare(self, node) |
visit_Call(self, node) |
visit_Repr(self, node) |
visit_Attribute(self, node) |
visit_Subscript(self, node) |
visit_Name(self, node) |
visit_List(self, node) |
visit_Tuple(self, node) |
visit_comprehension(self, node) |
visit_excepthandler(self, node) |
visit_arguments(self, node) |
visit_keyword(self, node) |
visit_alias(self, node) |
visit_Slice(self, node) |
visit_ExtSlice(self, node) |
visit_Index(self, node) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`